package com.chinaitop.depot.intelligent.operation.controller;

import com.chinaitop.depot.intelligent.operation.model.TTemperatureDetection;
import com.chinaitop.depot.intelligent.operation.service.TTemService;
import com.github.pagehelper.PageInfo;
import com.unissoft.model.ResponseEntity;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
@RequestMapping(value = "/intelligents/tem")
@Api(value = "TTemController", description = "温湿度检测")
public class TTemController {

    @Autowired
    private TTemService temService;

   
    @RequestMapping(value = "/getList", method = RequestMethod.GET)
    @ApiOperation(value = "查询温湿度检测列表", notes = "查询温湿度检测，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "库点编码", paramType = "query"),
            @ApiImplicitParam(name = "cfId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "kssj", value = "检测的开始时间", paramType = "query"),
            @ApiImplicitParam(name = "jssj", value = "检测的结束时间", paramType = "query")
    })
   public ResponseEntity<PageInfo<TTemperatureDetection>> getList(Integer pageNum, Integer pageSize, Integer cfId, String kssj,String jssj,Integer orgId) throws Exception {
        List<TTemperatureDetection> list = null;
        try {
            list = temService.getList(pageNum,pageSize,cfId,kssj,jssj,orgId);
        } catch (Exception e) {
            e.printStackTrace();
            ResponseEntity.failed(e.getMessage());
        }
        PageInfo<TTemperatureDetection> pageInfo = new PageInfo<TTemperatureDetection>(list);
        return ResponseEntity.ok(pageInfo);
    }

    
    @RequestMapping(value = "/getById", method = RequestMethod.GET)
    @ApiOperation(value = "根据id查询信息", notes = "根据id查询信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query")
    })
    public ResponseEntity<TTemperatureDetection> getById(String id) {
    	TTemperatureDetection tTemperatureDetection = null;
        if (StringUtils.isNotBlank(id)) {
        	tTemperatureDetection = temService.getById(id);
        } else {
            return ResponseEntity.failed("ID数据有误!");
        }
        return ResponseEntity.ok(tTemperatureDetection);
    }

    @RequestMapping(value = "/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "数据更新与添加", notes = "数据更新与添加")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tempJson", value = "表数据json串", paramType = "form")
    })
    public ResponseEntity save(String tempJson) {
        try {
        	temService.save(tempJson);
        } catch (Exception e) {
            e.printStackTrace();
            ResponseEntity.failed(e.getMessage());
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "/deleteById", method = RequestMethod.POST)
    @ApiOperation(value = "根据id删除信息", notes = "根据id删除信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "温湿度id", paramType = "query")
    })
    public ResponseEntity deleteById(String id) {
        if (StringUtils.isNotBlank(id)) {
            int count = temService.deleteById(id);
            if (count > 0) {
                return ResponseEntity.ok();
            } else {
                return ResponseEntity.failed("删除失败!");
            }
        }
        return ResponseEntity.failed("ID数据有误!");
    }

    
}
