package com.chinaitop.depot.intelligent.operation.service.impl;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.intelligent.operation.mapper.TFumigationOperationsMapper;
import com.chinaitop.depot.intelligent.operation.mapper.TTemperatureDetectionMapper;
import com.chinaitop.depot.intelligent.operation.model.TFumigationOperations;
import com.chinaitop.depot.intelligent.operation.model.TFumigationOperationsExample;
import com.chinaitop.depot.intelligent.operation.service.TFumService;
import com.chinaitop.depot.intelligent.utils.ParameterUtil;
import com.chinaitop.depot.intelligent.utils.UuidUtils;
import com.github.pagehelper.PageHelper;

@Service
public class TFumServiceImpl implements TFumService {
    
	@Autowired
    private TFumigationOperationsMapper fumMapper;
	
	@Autowired
    private TTemperatureDetectionMapper tempMapper;

	public List<TFumigationOperations> getList(Integer pageNum, Integer pageSize, Integer cfId, String kssj,String jssj,
			Integer orgId) throws Exception {
		
		TFumigationOperationsExample tFumigationOperationsExample = new TFumigationOperationsExample();
		tFumigationOperationsExample.setDistinct(true);
		TFumigationOperationsExample.Criteria criteria = tFumigationOperationsExample.createCriteria();
        if (StringUtils.isNotEmpty(cfId+"")) {
            criteria.andCfIdEqualTo(cfId);
        }
        if (StringUtils.isNotEmpty(orgId+"")) {
        	criteria.andOrgIdEqualTo(orgId);
        }
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
        if(StringUtils.isNotEmpty(kssj)){
            Date ksdate = simpleDateFormat.parse(kssj);
            criteria.andCjsjGreaterThanOrEqualTo(ksdate);
        }
        if(StringUtils.isNotEmpty(jssj)){
            Date jsdate = simpleDateFormat.parse(jssj);
            criteria.andCjsjLessThanOrEqualTo(jsdate);
        }
        
        tFumigationOperationsExample.setOrderByClause("cjsj desc");
        if (null != pageNum && null != pageSize) {
            PageHelper.startPage(pageNum, pageSize);
        }
        return fumMapper.selectByExample(tFumigationOperationsExample);
        
	}

	@Override
	public TFumigationOperations getById(String id) {
		
		TFumigationOperationsExample tFumigationOperationsExample = new TFumigationOperationsExample();
		TFumigationOperationsExample.Criteria criteria = tFumigationOperationsExample.createCriteria();
		criteria.andIdEqualTo(id);
		List<TFumigationOperations> list = fumMapper.selectByExample(tFumigationOperationsExample);
		if(list.size()>0){
			return list.get(0);
		}else{
			return new TFumigationOperations();
		}
		
	}

	@Override
	public void save(String fumJson) {
		
        if (StringUtils.isNotBlank(fumJson)) {
			
        	TFumigationOperations fum;
			try {
				JSONObject jsonObject = JSON.parseObject(fumJson);
				fum = JSONObject.toJavaObject(jsonObject , TFumigationOperations.class);
				if (StringUtils.isNotBlank(fum.getId())) {
					TFumigationOperationsExample tFumigationOperationsExample = new TFumigationOperationsExample();
					TFumigationOperationsExample.Criteria criteria = tFumigationOperationsExample.createCriteria();
					criteria.andIdEqualTo(fum.getId());
					fumMapper.updateByExampleSelective(fum, tFumigationOperationsExample);
	            } else {
	            	//熏蒸检测单号
	                Map<String,Object> map = new HashMap<String, Object>();
	                map.put("orgId", fum.getOrgId());
	                map.put("cfId", fum.getCfId());
	                map.put("updateTime", ParameterUtil.string2datetime(fum.getCjsj().toString()));
	                List<Map<String,Object>> jcdList = tempMapper.getJcd(map);
	                String jcd = ObjectUtils.toString(jcdList.get(0).get("jcd"));
	                fum.setXzzydh(jcd);
	                fum.setId(UuidUtils.getCode());
	                fumMapper.insert(fum);
	            }
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			
        }
		
	}

	@Override
	public int deleteById(String id) {
		// TODO Auto-generated method stub
		TFumigationOperationsExample tFumigationOperationsExample = new TFumigationOperationsExample();
		TFumigationOperationsExample.Criteria criteria = tFumigationOperationsExample.createCriteria();
		criteria.andIdEqualTo(id);
		return fumMapper.deleteByExample(tFumigationOperationsExample);
	}

}
