package com.chinaitop.depot.intelligent.operation.service.impl;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.intelligent.operation.mapper.TGasDetectionMapper;
import com.chinaitop.depot.intelligent.operation.mapper.TTemperatureDetectionMapper;
import com.chinaitop.depot.intelligent.operation.model.TGasDetection;
import com.chinaitop.depot.intelligent.operation.model.TGasDetectionExample;
import com.chinaitop.depot.intelligent.operation.service.TGasService;
import com.chinaitop.depot.intelligent.utils.ParameterUtil;
import com.chinaitop.depot.intelligent.utils.UuidUtils;
import com.github.pagehelper.PageHelper;

@Service
public class TGasServiceImpl implements TGasService {
    @Autowired
    private TGasDetectionMapper gasMapper;
    
    @Autowired
    private TTemperatureDetectionMapper tempMapper;

	@Override
	public List<TGasDetection> getList(Integer pageNum, Integer pageSize, Integer cfId, String kssj,String jssj,
			Integer orgId) throws Exception {
		
		TGasDetectionExample tGasDetectionExample = new TGasDetectionExample();
		tGasDetectionExample.setDistinct(true);
		TGasDetectionExample.Criteria criteria = tGasDetectionExample.createCriteria();
        if (StringUtils.isNotEmpty(cfId+"")) {
            criteria.andCfIdEqualTo(cfId);
        }
        if (StringUtils.isNotEmpty(orgId+"")) {
        	criteria.andOrgIdEqualTo(orgId);
        }
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
        if(StringUtils.isNotEmpty(kssj)){
            Date ksdate = simpleDateFormat.parse(kssj);
            criteria.andCjsjGreaterThanOrEqualTo(ksdate);
        }
        if(StringUtils.isNotEmpty(jssj)){
            Date jsdate = simpleDateFormat.parse(jssj);
            criteria.andCjsjLessThanOrEqualTo(jsdate);
        }
        
        tGasDetectionExample.setOrderByClause("cjsj desc");
        if (null != pageNum && null != pageSize) {
            PageHelper.startPage(pageNum, pageSize);
        }
        return gasMapper.selectByExample(tGasDetectionExample);
        
	}

	@Override
	public TGasDetection getById(String id) {
		TGasDetectionExample tGasDetectionExample = new TGasDetectionExample();
		tGasDetectionExample.setDistinct(true);
		TGasDetectionExample.Criteria criteria = tGasDetectionExample.createCriteria();
		criteria.andIdEqualTo(id);
		List<TGasDetection> list = gasMapper.selectByExample(tGasDetectionExample);
		if(list.size()>0){
			return list.get(0);
		}else{
			return new TGasDetection();
		}
	}

	@Override
	public void save(String gasJson) {
		
        if (StringUtils.isNotBlank(gasJson)) {
			
        	TGasDetection gas;
			try {
				JSONObject jsonObject = JSON.parseObject(gasJson);
				gas = JSONObject.toJavaObject(jsonObject , TGasDetection.class);
				if (StringUtils.isNotBlank(gas.getId())) {
					TGasDetectionExample tGasDetectionExample = new TGasDetectionExample();
					TGasDetectionExample.Criteria criteria = tGasDetectionExample.createCriteria();
					criteria.andIdEqualTo(gas.getId());
					gasMapper.updateByExampleSelective(gas, tGasDetectionExample);
	            } else {
	            	//检测单号
	                Map<String,Object> map = new HashMap<String, Object>();
	                map.put("orgId", gas.getOrgId());
	                map.put("cfId", gas.getCfId());
	                map.put("updateTime", ParameterUtil.string2datetime(gas.getJcsj().toString()));
	                List<Map<String,Object>> jcdList = tempMapper.getJcd(map);
	                String jcd = ObjectUtils.toString(jcdList.get(0).get("jcd"));
	                gas.setQtjcdh(jcd);
	                gas.setId(UuidUtils.getCode());
	                gasMapper.insert(gas);
	            }
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			
        }
		
	}

	@Override
	public int deleteById(String id) {
		// TODO Auto-generated method stub
		TGasDetectionExample tGasDetectionExample = new TGasDetectionExample();
		TGasDetectionExample.Criteria criteria = tGasDetectionExample.createCriteria();
		criteria.andIdEqualTo(id);
		return gasMapper.deleteByExample(tGasDetectionExample);
	}

}
