package com.chinaitop.depot.intelligent.operation.service.impl;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.intelligent.operation.mapper.TPestDetectionMapper;
import com.chinaitop.depot.intelligent.operation.mapper.TTemperatureDetectionMapper;
import com.chinaitop.depot.intelligent.operation.model.TPestDetection;
import com.chinaitop.depot.intelligent.operation.model.TPestDetectionExample;
import com.chinaitop.depot.intelligent.operation.service.TPestService;
import com.chinaitop.depot.intelligent.utils.ParameterUtil;
import com.chinaitop.depot.intelligent.utils.UuidUtils;
import com.github.pagehelper.PageHelper;

@Service
public class TPestServiceImpl implements TPestService {
    @Autowired
    private TPestDetectionMapper pestMapper;
    
    @Autowired
    private TTemperatureDetectionMapper tempMapper;

	public List<TPestDetection> getList(Integer pageNum, Integer pageSize, Integer cfId, String kssj,String jssj,
			Integer orgId) throws Exception {
		
		TPestDetectionExample tPestDetectionExample = new TPestDetectionExample();
		tPestDetectionExample.setDistinct(true);
		TPestDetectionExample.Criteria criteria = tPestDetectionExample.createCriteria();
        if (StringUtils.isNotEmpty(cfId+"")) {
            criteria.andCfIdEqualTo(cfId);
        }
        if (StringUtils.isNotEmpty(orgId+"")) {
        	criteria.andOrgIdEqualTo(orgId);
        }
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
        if(StringUtils.isNotEmpty(kssj)){
            Date ksdate = simpleDateFormat.parse(kssj);
            criteria.andCjsjGreaterThanOrEqualTo(ksdate);
        }
        if(StringUtils.isNotEmpty(jssj)){
            Date jsdate = simpleDateFormat.parse(jssj);
            criteria.andCjsjLessThanOrEqualTo(jsdate);
        }
        
        tPestDetectionExample.setOrderByClause("cjsj desc");
        if (null != pageNum && null != pageSize) {
            PageHelper.startPage(pageNum, pageSize);
        }
        return pestMapper.selectByExample(tPestDetectionExample);
        
	}

	@Override
	public TPestDetection getById(String id) {
		
		TPestDetectionExample tPestDetectionExample = new TPestDetectionExample();
		TPestDetectionExample.Criteria criteria = tPestDetectionExample.createCriteria();
		criteria.andIdEqualTo(id);
		List<TPestDetection> list = pestMapper.selectByExample(tPestDetectionExample);
		if(list.size()>0){
			return list.get(0);
		}else{
			return new TPestDetection();
		}
		
	}

	@Override
	public void save(String pestJson) {
		
        if (StringUtils.isNotBlank(pestJson)) {
			
        	TPestDetection pest;
			try {
				JSONObject jsonObject = JSON.parseObject(pestJson);
				pest = JSONObject.toJavaObject(jsonObject , TPestDetection.class);
				if (StringUtils.isNotBlank(pest.getId())) {
					TPestDetectionExample tPestDetectionExample = new TPestDetectionExample();
					TPestDetectionExample.Criteria criteria = tPestDetectionExample.createCriteria();
					criteria.andIdEqualTo(pest.getId());
					pestMapper.updateByExampleSelective(pest, tPestDetectionExample);
	            } else {
	            	//害虫检测单号
	                Map<String,Object> map = new HashMap<String, Object>();
	                map.put("orgId", pest.getOrgId());
	                map.put("cfId", pest.getCfId());
	                map.put("updateTime", ParameterUtil.string2datetime(pest.getJcsj().toString()));
	                List<Map<String,Object>> jcdList = tempMapper.getJcd(map);
	                String jcd = ObjectUtils.toString(jcdList.get(0).get("jcd"));
	                pest.setHcjcdh(jcd);
	                pest.setId(UuidUtils.getCode());
	            	pestMapper.insert(pest);
	            }
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			
        }
		
	}

	@Override
	public int deleteById(String id) {
		// TODO Auto-generated method stub
		TPestDetectionExample tPestDetectionExample = new TPestDetectionExample();
		TPestDetectionExample.Criteria criteria = tPestDetectionExample.createCriteria();
		criteria.andIdEqualTo(id);
		return pestMapper.deleteByExample(tPestDetectionExample);
	}

}
