package com.chinaitop.depot.intelligent.operation.service.impl;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.intelligent.operation.mapper.TTemperatureDetectionMapper;
import com.chinaitop.depot.intelligent.operation.model.TTemperatureDetection;
import com.chinaitop.depot.intelligent.operation.model.TTemperatureDetectionExample;
import com.chinaitop.depot.intelligent.operation.service.TTemService;
import com.chinaitop.depot.intelligent.utils.ParameterUtil;
import com.chinaitop.depot.intelligent.utils.UuidUtils;
import com.github.pagehelper.PageHelper;

@Service
public class TTemServiceImpl implements TTemService {
    @Autowired
    private TTemperatureDetectionMapper tempMapper;

	@Override
	public List<TTemperatureDetection> getList(Integer pageNum, Integer pageSize, Integer cfId, String kssj,String jssj,
			Integer orgId) throws Exception {
		
		TTemperatureDetectionExample tTemperatureDetectionExample = new TTemperatureDetectionExample();
		tTemperatureDetectionExample.setDistinct(true);
		TTemperatureDetectionExample.Criteria criteria = tTemperatureDetectionExample.createCriteria();
        if (StringUtils.isNotEmpty(cfId+"")) {
            criteria.andCfIdEqualTo(cfId);
        }
        if (StringUtils.isNotEmpty(orgId+"")) {
        	criteria.andOrgIdEqualTo(orgId);
        }
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
        if(StringUtils.isNotEmpty(kssj)){
            Date ksdate = simpleDateFormat.parse(kssj);
            criteria.andCjsjGreaterThanOrEqualTo(ksdate);
        }
        if(StringUtils.isNotEmpty(jssj)){
            Date jsdate = simpleDateFormat.parse(jssj);
            criteria.andCjsjLessThanOrEqualTo(jsdate);
        }
        
        tTemperatureDetectionExample.setOrderByClause("cjsj desc");
        if (null != pageNum && null != pageSize) {
            PageHelper.startPage(pageNum, pageSize);
        }
        return tempMapper.selectByExample(tTemperatureDetectionExample);
        
	}

	@Override
	public TTemperatureDetection getById(String id) {
		
		return tempMapper.selectByPrimaryKey(id);
	}

	@Override
	public void save(String tempJson) {
		
        if (StringUtils.isNotBlank(tempJson)) {
			
        	TTemperatureDetection temp;
			try {
				JSONObject jsonObject = JSON.parseObject(tempJson);
				temp = JSONObject.toJavaObject(jsonObject , TTemperatureDetection.class);
				if (StringUtils.isNotBlank(temp.getId())) {
					TTemperatureDetectionExample tTemperatureDetectionExample = new TTemperatureDetectionExample();
					TTemperatureDetectionExample.Criteria criteria = tTemperatureDetectionExample.createCriteria();
					criteria.andIdEqualTo(temp.getId());
					tempMapper.updateByExampleSelective(temp, tTemperatureDetectionExample);
	            } else {
	            	//检测单号
	                Map<String,Object> map = new HashMap<String, Object>();
	                map.put("orgId", temp.getOrgId());
	                map.put("cfId", temp.getCfId());
	                map.put("updateTime", ParameterUtil.string2datetime(temp.getJcsj().toString()));
	                List<Map<String,Object>> jcdList = tempMapper.getJcd(map);
	                String jcd = ObjectUtils.toString(jcdList.get(0).get("jcd"));
	                temp.setWsdjcdh(jcd);
	            	temp.setId(UuidUtils.getCode());
	            	tempMapper.insert(temp);
	            }
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			
        }
		
	}

	@Override
	public int deleteById(String id) {
		// TODO Auto-generated method stub
		TTemperatureDetectionExample tTemperatureDetectionExample = new TTemperatureDetectionExample();
		TTemperatureDetectionExample.Criteria criteria = tTemperatureDetectionExample.createCriteria();
		criteria.andIdEqualTo(id);
		return tempMapper.deleteByExample(tTemperatureDetectionExample);
	}

}
