package com.chinaitop.depot.intelligent.operation.service.impl;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.intelligent.operation.mapper.TPestDetectionMapper;
import com.chinaitop.depot.intelligent.operation.mapper.TTemperatureDetectionMapper;
import com.chinaitop.depot.intelligent.operation.mapper.TVentilationOperationMapper;
import com.chinaitop.depot.intelligent.operation.model.TPestDetection;
import com.chinaitop.depot.intelligent.operation.model.TPestDetectionExample;
import com.chinaitop.depot.intelligent.operation.model.TVentilationOperation;
import com.chinaitop.depot.intelligent.operation.model.TVentilationOperationExample;
import com.chinaitop.depot.intelligent.operation.service.TPestService;
import com.chinaitop.depot.intelligent.operation.service.TVenService;
import com.chinaitop.depot.intelligent.utils.ParameterUtil;
import com.chinaitop.depot.intelligent.utils.UuidUtils;
import com.github.pagehelper.PageHelper;

@Service
public class TVenServiceImpl implements TVenService {
    
	@Autowired
    private TVentilationOperationMapper venMapper;
	
	@Autowired
    private TTemperatureDetectionMapper tempMapper;

	public List<TVentilationOperation> getList(Integer pageNum, Integer pageSize, Integer cfId, String kssj,String jssj,
			Integer orgId) throws Exception {
		
		TVentilationOperationExample tVentilationOperationExample = new TVentilationOperationExample();
		tVentilationOperationExample.setDistinct(true);
		TVentilationOperationExample.Criteria criteria = tVentilationOperationExample.createCriteria();
        if (StringUtils.isNotEmpty(cfId+"")) {
            criteria.andCfIdEqualTo(cfId);
        }
        if (StringUtils.isNotEmpty(orgId+"")) {
        	criteria.andOrgIdEqualTo(orgId);
        }
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
        if(StringUtils.isNotEmpty(kssj)){
            Date ksdate = simpleDateFormat.parse(kssj);
            criteria.andCjsjGreaterThanOrEqualTo(ksdate);
        }
        if(StringUtils.isNotEmpty(jssj)){
            Date jsdate = simpleDateFormat.parse(jssj);
            criteria.andCjsjLessThanOrEqualTo(jsdate);
        }
        
        tVentilationOperationExample.setOrderByClause("cjsj desc");
        if (null != pageNum && null != pageSize) {
            PageHelper.startPage(pageNum, pageSize);
        }
        return venMapper.selectByExample(tVentilationOperationExample);
        
	}

	@Override
	public TVentilationOperation getById(String id) {
		
		TVentilationOperationExample tVentilationOperationExample = new TVentilationOperationExample();
		TVentilationOperationExample.Criteria criteria = tVentilationOperationExample.createCriteria();
		criteria.andIdEqualTo(id);
		List<TVentilationOperation> list = venMapper.selectByExample(tVentilationOperationExample);
		if(list.size()>0){
			return list.get(0);
		}else{
			return new TVentilationOperation();
		}
		
	}

	@Override
	public void save(String venJson) {
		
        if (StringUtils.isNotBlank(venJson)) {
			
        	TVentilationOperation ven;
			try {
				JSONObject jsonObject = JSON.parseObject(venJson);
				ven = JSONObject.toJavaObject(jsonObject , TVentilationOperation.class);
				if (StringUtils.isNotBlank(ven.getId())) {
					TVentilationOperationExample tVentilationOperationExample = new TVentilationOperationExample();
					TVentilationOperationExample.Criteria criteria = tVentilationOperationExample.createCriteria();
					criteria.andIdEqualTo(ven.getId());
					venMapper.updateByExampleSelective(ven, tVentilationOperationExample);
	            } else {
	            	//通风检测单号
	                Map<String,Object> map = new HashMap<String, Object>();
	                map.put("orgId", ven.getOrgId());
	                map.put("cfId", ven.getCfId());
	                map.put("updateTime", ParameterUtil.string2datetime(ven.getCjsj().toString()));
	                List<Map<String,Object>> jcdList = tempMapper.getJcd(map);
	                String jcd = ObjectUtils.toString(jcdList.get(0).get("jcd"));
	                ven.setTfzydh(jcd);
	                ven.setId(UuidUtils.getCode());
	                venMapper.insert(ven);
	            }
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			
        }
		
	}

	@Override
	public int deleteById(String id) {
		// TODO Auto-generated method stub
		TVentilationOperationExample tVentilationOperationExample = new TVentilationOperationExample();
		TVentilationOperationExample.Criteria criteria = tVentilationOperationExample.createCriteria();
		criteria.andIdEqualTo(id);
		return venMapper.deleteByExample(tVentilationOperationExample);
	}

}
